#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 charset
version:              0.3.8
visibility:           public
id:                   charset-0.3.8-4iWjhAmMSYyAaq3GWZzCtv
key:                  charset-0.3.8-4iWjhAmMSYyAaq3GWZzCtv
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  23df60bbe2b867ffc253b98bb8f27a38
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-8.10.5/site-local/charset-0.3.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/charset-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/charset-0.3.8
hs-libraries:         HScharset-0.3.8-4iWjhAmMSYyAaq3GWZzCtv
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

